@@ -17,12 +17,11 @@
 #include <QStandardPaths>
 
 // KF includes
-#include <kwidgetsaddons_version.h>
 #include <KActionCollection>
 #include <KConfigGroup>
 #include <KMessageBox>
 #include <KSharedConfig>
-#include <KStandardGameAction>
+#include <KGameStandardAction>
 #include <KLocalizedString>
 #include <KSelectAction>
 // Application specific includes
@@ -70,9 +69,10 @@ Mainwindow::Mainwindow(QWidget *parent)
     QStringList themeList;
     const QStringList dirs = QStandardPaths::locateAll(QStandardPaths::AppDataLocation, QStringLiteral("grafix"), QStandardPaths::LocateDirectory);
     for (const QString& dir : dirs) {
-        const QStringList fileNames = QDir(dir).entryList(QStringList() << QStringLiteral("*.desktop"));
+        const QStringList fileNames = QDir(dir).entryList({QStringLiteral("*.desktop")});
+        themeList.reserve(themeList.size() + fileNames.size());
         for (const QString& file : fileNames) {
-            themeList.append(dir + '/' + file);
+            themeList.append(dir + QLatin1Char('/') + file);
         }
     }
     if (themeList.isEmpty())
@@ -83,10 +83,9 @@ Mainwindow::Mainwindow(QWidget *parent)
     }
 
     // Read theme files
-    for (int i = 0; i < themeList.size(); i++)
-    {
-        KConfig themeInfo(themeList.at(i), KConfig::SimpleConfig);
-        KConfigGroup themeGroup(&themeInfo, "Theme");
+    for (const QString &themePath : std::as_const(themeList)) {
+        KConfig themeInfo(themePath, KConfig::SimpleConfig);
+        KConfigGroup themeGroup(&themeInfo, QStringLiteral("Theme"));
         QString name = themeGroup.readEntry("Name", QString());
         QString file = themeGroup.readEntry("File", QString());
         bool isDefault = themeGroup.readEntry("Default", false);
@@ -94,7 +93,7 @@ Mainwindow::Mainwindow(QWidget *parent)
         if (mThemeDefault.isNull()) mThemeDefault = name;
         if (isDefault) mThemeDefault = name;
 
-        if (global_debug > 0) qCDebug(LSKAT_LOG) << "Found theme: " << themeList.at(i) << " Name(i18n)=" << name << " File=" << file << " default=" << isDefault;
+        if (global_debug > 0) qCDebug(LSKAT_LOG) << "Found theme: " << themePath << " Name(i18n)=" << name << " File=" << file << " default=" << isDefault;
     }
     mThemeIndexNo = themeIdxFromName(mThemeDefault);
 
@@ -216,7 +215,7 @@ void Mainwindow::saveProperties()
     KConfig *config = KSharedConfig::openConfig().data();
 
     // Program data
-    KConfigGroup cfg = config->group("ProgramData");
+    KConfigGroup cfg = config->group(QStringLiteral("ProgramData"));
     cfg.writeEntry("startplayer", mStartPlayer);
     cfg.writeEntry("ThemeIndexNo", mThemeIndexNo);
 
@@ -231,7 +230,7 @@ void Mainwindow::readProperties()
     KConfig *config = KSharedConfig::openConfig().data();
 
     // Program data
-    KConfigGroup cfg = config->group("ProgramData");
+    KConfigGroup cfg = config->group(QStringLiteral("ProgramData"));
 
     // Theme number
     mThemeIndexNo = cfg.readEntry("ThemeIndexNo", themeIdxFromName(mThemeDefault));
@@ -292,7 +291,7 @@ AbstractInput *Mainwindow::createInput(
 void Mainwindow::startGame()
 {
     // Enable game action
-    QLatin1String endName(KStandardGameAction::name(KStandardGameAction::End));
+    const QString endName(KGameStandardAction::name(KGameStandardAction::End));
     ACTION(endName)->setEnabled(true);
 
     // Deal cards to player - Shuffle card deck and reset pile
@@ -329,7 +328,7 @@ void Mainwindow::startGame()
 // Here a game over is signalled
 void Mainwindow::gameOver(int /*winner*/)
 {
-    QLatin1String endName(KStandardGameAction::name(KStandardGameAction::End));
+    const QString endName(KGameStandardAction::name(KGameStandardAction::End));
     ACTION(endName)->setEnabled(false);
     statusBar()->showMessage(i18n("Game Over. Please start a new game."));
 
@@ -354,21 +353,21 @@ void Mainwindow::initGUI()
     QAction *action;
 
     // Start a new game
-    action = KStandardGameAction::gameNew(this, &Mainwindow::menuNewLSkatGame, actionCollection());
+    action = KGameStandardAction::gameNew(this, &Mainwindow::menuNewLSkatGame, actionCollection());
     if (global_demo_mode) action->setEnabled(false);
 
     // Clear all time statistics
-    action = KStandardGameAction::clearStatistics(this, &Mainwindow::menuClearStatistics, actionCollection());
+    action = KGameStandardAction::clearStatistics(this, &Mainwindow::menuClearStatistics, actionCollection());
     action->setWhatsThis(i18n("Clears the all time statistics which is kept in all sessions."));
     if (global_demo_mode) action->setEnabled(false);
 
     // End a game
-    action = KStandardGameAction::end(this, &Mainwindow::menuEndGame, actionCollection());
+    action = KGameStandardAction::end(this, &Mainwindow::menuEndGame, actionCollection());
     action->setWhatsThis(i18n("Ends a currently played game. No winner will be declared."));
     action->setEnabled(false);
 
     // Quit the program
-    action = KStandardGameAction::quit(this, &QWidget::close, actionCollection());
+    action = KGameStandardAction::quit(this, &QWidget::close, actionCollection());
     action->setWhatsThis(i18n("Quits the program."));
 
     // Determine start player
@@ -377,11 +376,10 @@ void Mainwindow::initGUI()
     connect(startPlayerAct, &KSelectAction::indexTriggered, this, &Mainwindow::menuStartplayer);
     startPlayerAct->setToolTip(i18n("Changing starting player..."));
     startPlayerAct->setWhatsThis(i18n("Chooses which player begins the next game."));
-    QStringList list;
-    list.clear();
-    list.append(i18n("Player &1"));
-    list.append(i18n("Player &2"));
-    startPlayerAct->setItems(list);
+    startPlayerAct->setItems({
+        i18n("Player &1"),
+        i18n("Player &2"),
+    });
     if (global_demo_mode) startPlayerAct->setEnabled(false);
 
     // Determine who plays player 1
@@ -390,10 +388,11 @@ void Mainwindow::initGUI()
     connect(player1Act, &KSelectAction::indexTriggered, this, &Mainwindow::menuPlayer1By);
     player1Act->setToolTip(i18n("Changing who plays player 1..."));
     player1Act->setWhatsThis(i18n("Changing who plays player 1."));
-    list.clear();
-    list.append(i18n("&Mouse"));
-    list.append(i18n("&Computer"));
-    player1Act->setItems(list);
+    const QStringList inputDevices {
+        i18n("&Mouse"),
+        i18n("&Computer"),
+    };
+    player1Act->setItems(inputDevices);
     if (global_demo_mode) player1Act->setEnabled(false);
 
     // Determine who plays player 2
@@ -402,7 +401,7 @@ void Mainwindow::initGUI()
     connect(player2Act, &KSelectAction::indexTriggered, this, &Mainwindow::menuPlayer2By);
     player2Act->setToolTip(i18n("Changing who plays player 2..."));
     player2Act->setWhatsThis(i18n("Changing who plays player 2."));
-    player2Act->setItems(list);
+    player2Act->setItems(inputDevices);
     if (global_demo_mode) player2Act->setEnabled(false);
 
     // Add all theme files to the menu
@@ -421,7 +420,6 @@ void Mainwindow::initGUI()
     // Choose card deck
     QAction *action1 = actionCollection()->addAction(QStringLiteral("select_carddeck"));
     action1->setText(i18n("Select &Card Deck..."));
-    actionCollection()->setDefaultShortcut(action1, QKeySequence(Qt::Key_F10));
     connect(action1, &QAction::triggered, this, &Mainwindow::menuCardDeck);
     action1->setToolTip(i18n("Configure card decks..."));
     action1->setWhatsThis(i18n("Choose how the cards should look."));
@@ -468,7 +466,7 @@ void Mainwindow::menuCardDeck()
 {
     QString front = mCardTheme;
 
-    KConfigGroup grp = KSharedConfig::openConfig()->group("ProgramData");
+    KConfigGroup grp = KSharedConfig::openConfig()->group(QStringLiteral("ProgramData"));
     KCardWidget *cardwidget = new KCardWidget();
     QPointer<KCardDialog> dlg;
 
@@ -502,11 +500,7 @@ void Mainwindow::menuClearStatistics()
     message = i18n("Do you really want to clear the all time "
                     "statistical data?");
 
-#if KWIDGETSADDONS_VERSION >= QT_VERSION_CHECK(5, 100, 0)
     if (KMessageBox::PrimaryAction == KMessageBox::questionTwoActions(this,
-#else
-    if (KMessageBox::Yes == KMessageBox::questionYesNo(this,
-#endif
                                                        message,
                                                        QString(),
                                                        KStandardGuiItem::clear(),
